.. _dg-examples-index:

dg
==

.. toctree::
   :maxdepth: 2

   advection_1D.py <dg-advection_1D>
   advection_2D.py <dg-advection_2D>
   advection_diffusion_2D.py <dg-advection_diffusion_2D>
   burgers_2D.py <dg-burgers_2D>
   dg_plot_1D.py <dg-dg_plot_1D>
   example_dg_common.py <dg-example_dg_common>
   imperative_burgers_1D.py <dg-imperative_burgers_1D>
   laplace_2D.py <dg-laplace_2D>
